@@ -30,7 +30,7 @@
  DAMAGE. 
  =========================================================================*/
 
-/** @file
+/*
  *	memory allocation functions
  */
 
@@ -40,8 +40,6 @@
 
 #include "global-cscope.h" /* for postfatal() */
 
-static char const rcsid[] = "$Id: alloc.c,v 1.2 2012/10/13 07:01:58 shigio Exp $";
-
 static	void	*alloctest(void *p);
 
 /* let autoconf find out if <stdlib.h> is available. This test will
@@ -61,7 +59,7 @@ my_strdup(char *s)
 }
 
 
-/** version of @NAME{malloc} that only returns if successful */
+/** version of malloc that only returns if successful */
 void *
 mymalloc(size_t size)
 {
@@ -69,7 +67,7 @@ mymalloc(size_t size)
 }
 
 
-/** version of @NAME{calloc} that only returns if successful */
+/** version of calloc that only returns if successful */
 void *
 mycalloc(size_t nelem, size_t size)
 {
@@ -77,7 +75,7 @@ mycalloc(size_t nelem, size_t size)
 }
 
 
-/** version of @NAME{realloc} that only returns if successful */
+/** version of realloc that only returns if successful */
 void *
 myrealloc(void *p, size_t size)
 {
